# xxurl
>__handle url,javascript-style API__

# install
>__pip3 install xxurl__


# _class_ URL
-----------------------------------------------------------------------
>├──0. [\_\_init\_\_.0](xxurl/Images/URL.__init__.0.png)  <br>
├──1. [\_\_init\_\_.1](xxurl/Images/URL.__init__.1.png)  <br>
├──2. [\_\_init\_\_.2](xxurl/Images/URL.__init__2.png.0.png)  <br>
├──3. [\_\_init\_\_.3](xxurl/Images/URL.__init__.3.png)  <br>
├──4. [repl_hash](xxurl/Images/URL.repl_hash.0.png)  <br>
├──5. [repl_host](xxurl/Images/URL.repl_host.0.png)  <br>
├──6. [repl_hostname](xxurl/Images/URL.repl_hostname.0.png)  <br>
├──7. [repl_netloc](xxurl/Images/URL.repl_netloc.0.png)  <br>
├──8. [repl_params](xxurl/Images/URL.repl_params.0.png)  <br>
├──9. [repl_password](xxurl/Images/URL.repl_password.0.png)  <br>
├──10. [repl_path](xxurl/Images/URL.repl_path.0.png)  <br>
├──11. [repl_port](xxurl/Images/URL.repl_port.0.png)  <br>
├──12. [repl_protocol](xxurl/Images/URL.repl_protocol.0.png)  <br>
├──13. [repl_query](xxurl/Images/URL.repl_query.0.png)  <br>
├──14. [repl_userinfo](xxurl/Images/URL.repl_userinfo.0.png)  <br>
├──15. [repl_username](xxurl/Images/URL.repl_username.0.png)  <br>
├──16. [searchParams.append](xxurl/Images/URL.searchParams.append.0.png)  <br>
├──17. [searchParams.delete](xxurl/Images/URL.searchParams.delete.0.png)  <br>
├──18. [searchParams.entries](xxurl/Images/URL.searchParams.entries.0.png)  <br>
├──19. [searchParams.get](xxurl/Images/URL.searchParams.get.0.png)  <br>
├──20. [searchParams.getAll](xxurl/Images/URL.searchParams.getAll.0.png)  <br>
├──21. [searchParams.has](xxurl/Images/URL.searchParams.has.0.png)  <br>
├──22. [searchParams.insert](xxurl/Images/URL.searchParams.insert.0.png)  <br>
├──23. [searchParams.prepend](xxurl/Images/URL.searchParams.prepend.0.png)  <br>
├──24. [searchParams.set](xxurl/Images/URL.searchParams.set.0.png)  <br>
├──25. [toDict](xxurl/Images/URL.toDict.0.png)  <br>
├──26. [toTuple](xxurl/Images/URL.toTuple.0.png)  <br>
-----------------------------------------------------------------------



# _class_ URLSearchParams
-----------------------------------------------------------------------
>├──0. [append](xxurl/Images/URLSearchParams.append.0.png)  <br>
├──1. [delete](xxurl/Images/URLSearchParams.delete.0.png)  <br>
├──2. [entries](xxurl/Images/URLSearchParams.entries.0.png)  <br>
├──3. [get](xxurl/Images/URLSearchParams.get.0.png)  <br>
├──4. [getAll](xxurl/Images/URLSearchParams.getAll.0.png)  <br>
├──5. [has](xxurl/Images/URLSearchParams.has.0.png)  <br>
├──6. [insert](xxurl/Images/URLSearchParams.insert.0.png)  <br>
├──7. [keys](xxurl/Images/URLSearchParams.keys.0.png)  <br>
├──8. [prepend](xxurl/Images/URLSearchParams.prepend.0.png)  <br>
├──9. [set](xxurl/Images/URLSearchParams.set.0.png)  <br>
├──10. [toString](xxurl/Images/URLSearchParams.toString.0.png)  <br>
├──11. [values](xxurl/Images/URLSearchParams.values.0.png)  <br>
-----------------------------------------------------------------------



# functions
-----------------------------------------------------------------------
├──0. [after_fragment_sp](xxurl/Images/after_fragment_sp.0.png)  <br>
├──1. [after_hash_sp](xxurl/Images/after_hash_sp.0.png)  <br>
├──2. [after_host](xxurl/Images/after_host.0.png)  <br>
├──3. [after_host_sp](xxurl/Images/after_host_sp.0.png)  <br>
├──4. [after_hostname](xxurl/Images/after_hostname.0.png)  <br>
├──5. [after_hostname_sp](xxurl/Images/after_hostname_sp.0.png)  <br>
├──6. [after_netloc_sp](xxurl/Images/after_netloc_sp.0.png)  <br>
├──7. [after_params](xxurl/Images/after_params.0.png)  <br>
├──8. [after_params_sp](xxurl/Images/after_params_sp.0.png)  <br>
├──9. [after_password](xxurl/Images/after_password.0.png)  <br>
├──10. [after_password_sp](xxurl/Images/after_password_sp.0.png)  <br>
├──11. [after_path](xxurl/Images/after_path.0.png)  <br>
├──12. [after_path_sp](xxurl/Images/after_path_sp.0.png)  <br>
├──13. [after_port](xxurl/Images/after_port.0.png)  <br>
├──14. [after_port_sp](xxurl/Images/after_port_sp.0.png)  <br>
├──15. [after_protocol](xxurl/Images/after_protocol.0.png)  <br>
├──16. [after_query](xxurl/Images/after_query.0.png)  <br>
├──17. [after_query_sp](xxurl/Images/after_query_sp.0.png)  <br>
├──18. [after_scheme](xxurl/Images/after_scheme.0.png)  <br>
├──19. [after_unpw](xxurl/Images/after_unpw.0.png)  <br>
├──20. [after_userinfo](xxurl/Images/after_userinfo.0.png)  <br>
├──21. [after_userinfo_sp](xxurl/Images/after_userinfo_sp.0.png)  <br>
├──22. [after_username](xxurl/Images/after_username.0.png)  <br>
├──23. [after_username_sp](xxurl/Images/after_username_sp.0.png)  <br>
├──24. [before_fragment](xxurl/Images/before_fragment.0.png)  <br>
├──25. [before_fragment_sp](xxurl/Images/before_fragment_sp.0.png)  <br>
├──26. [before_hash](xxurl/Images/before_hash.0.png)  <br>
├──27. [before_hash_sp](xxurl/Images/before_hash_sp.0.png)  <br>
├──28. [before_host](xxurl/Images/before_host.0.png)  <br>
├──29. [before_host_sp](xxurl/Images/before_host_sp.0.png)  <br>
├──30. [before_hostname](xxurl/Images/before_hostname.0.png)  <br>
├──31. [before_hostname_sp](xxurl/Images/before_hostname_sp.0.png)  <br>
├──32. [before_netloc](xxurl/Images/before_netloc.0.png)  <br>
├──33. [before_netloc_sp](xxurl/Images/before_netloc_sp.0.png)  <br>
├──34. [before_params](xxurl/Images/before_params.0.png)  <br>
├──35. [before_params_sp](xxurl/Images/before_params_sp.0.png)  <br>
├──36. [before_password](xxurl/Images/before_password.0.png)  <br>
├──37. [before_password_sp](xxurl/Images/before_password_sp.0.png)  <br>
├──38. [before_path](xxurl/Images/before_path.0.png)  <br>
├──39. [before_path_sp](xxurl/Images/before_path_sp.0.png)  <br>
├──40. [before_pathname](xxurl/Images/before_pathname.0.png)  <br>
├──41. [before_port](xxurl/Images/before_port.0.png)  <br>
├──42. [before_port_sp](xxurl/Images/before_port_sp.0.png)  <br>
├──43. [before_query](xxurl/Images/before_query.0.png)  <br>
├──44. [before_query_sp](xxurl/Images/before_query_sp.0.png)  <br>
├──45. [before_search](xxurl/Images/before_search.0.png)  <br>
├──46. [before_unpw](xxurl/Images/before_unpw.0.png)  <br>
├──47. [before_userinfo](xxurl/Images/before_userinfo.0.png)  <br>
├──48. [before_userinfo_sp](xxurl/Images/before_userinfo_sp.0.png)  <br>
├──49. [before_username](xxurl/Images/before_username.0.png)  <br>
├──50. [before_username_sp](xxurl/Images/before_username_sp.0.png)  <br>
├──52. [d2t](xxurl/Images/d2t.0.png)  <br>
├──53. [d2u](xxurl/Images/d2u.0.png)  <br>
├──54. [dict2qdl](xxurl/Images/dict2qdl.0.png)  <br>
├──.**_get absolute-url ,such as from form-action_** <br>
├──58. [get_abs_url](xxurl/Images/get_abs_url.0.png)  <br>
├──.**_get absolute-url ,such as from form-action_** <br>
├──59. [get_authority](xxurl/Images/get_authority.0.png)  <br>
├──60. [get_fragment](xxurl/Images/get_fragment.0.png)  <br>
├──61. [get_hash](xxurl/Images/get_hash.0.png)  <br>
├──62. [get_host](xxurl/Images/get_host.0.png)  <br>
├──63. [get_hostname](xxurl/Images/get_hostname.0.png)  <br>
├──64. [get_netloc](xxurl/Images/get_netloc.0.png)  <br>
├──65. [get_origin](xxurl/Images/get_origin.0.png)  <br>
├──66. [get_params](xxurl/Images/get_params.0.png)  <br>
├──67. [get_password](xxurl/Images/get_password.0.png)  <br>
├──68. [get_path](xxurl/Images/get_path.0.png)  <br>
├──69. [get_pathname](xxurl/Images/get_pathname.0.png)  <br>
├──70. [get_port](xxurl/Images/get_port.0.png)  <br>
├──71. [get_protocol](xxurl/Images/get_protocol.0.png)  <br>
├──72. [get_query](xxurl/Images/get_query.0.png)  <br>
├──73. [get_scheme](xxurl/Images/get_scheme.0.png)  <br>
├──74. [get_search](xxurl/Images/get_search.0.png)  <br>
├──75. [get_unpw](xxurl/Images/get_unpw.0.png)  <br>
├──76. [get_userinfo](xxurl/Images/get_userinfo.0.png)  <br>
├──77. [get_username](xxurl/Images/get_username.0.png)  <br>
├──78. [has_fragment](xxurl/Images/has_fragment.0.png)  <br>
├──79. [has_hash](xxurl/Images/has_hash.0.png)  <br>
├──80. [has_host](xxurl/Images/has_host.0.png)  <br>
├──81. [has_hostname](xxurl/Images/has_hostname.0.png)  <br>
├──82. [has_netloc](xxurl/Images/has_netloc.0.png)  <br>
├──83. [has_params](xxurl/Images/has_params.0.png)  <br>
├──84. [has_password](xxurl/Images/has_password.0.png)  <br>
├──85. [has_path](xxurl/Images/has_path.0.png)  <br>
├──86. [has_port](xxurl/Images/has_port.0.png)  <br>
├──87. [has_protocol](xxurl/Images/has_protocol.0.png)  <br>
├──88. [has_query](xxurl/Images/has_query.0.png)  <br>
├──89. [has_scheme](xxurl/Images/has_scheme.0.png)  <br>
├──90. [has_unpw](xxurl/Images/has_unpw.0.png)  <br>
├──91. [has_userinfo](xxurl/Images/has_userinfo.0.png)  <br>
├──92. [has_username](xxurl/Images/has_username.0.png)  <br>
├──94. [l2path](xxurl/Images/l2path.0.png)  <br>
├──95. [nin_d2t](xxurl/Images/nin_d2t.0.png)  <br>
├──96. [nin_d2u](xxurl/Images/nin_d2u.0.png)  <br>
├──97. [nin_get](xxurl/Images/nin_get.0.png)  <br>
├──98. [nin_set](xxurl/Images/nin_set.0.png)  <br>
├──99. [nin_t2d](xxurl/Images/nin_t2d.0.png)  <br>
├──100. [nin_t2u](xxurl/Images/nin_t2u.0.png)  <br>
├──101. [nin_to_attrname](xxurl/Images/nin_to_attrname.0.png)  <br>
├──102. [nin_u2d](xxurl/Images/nin_u2d.0.png)  <br>
├──103. [nin_u2t](xxurl/Images/nin_u2t.0.png)  <br>
├──106. [packup_host](xxurl/Images/packup_host.0.png)  <br>
├──107. [packup_netloc](xxurl/Images/packup_netloc.0.png)  <br>
├──108. [packup_unpw](xxurl/Images/packup_unpw.0.png)  <br>
├──109. [para2tl](xxurl/Images/para2tl.0.png)  <br>
├──110. [path2l](xxurl/Images/path2l.0.png)  <br>
├──.**_normalization_** <br>
├──51. [case_normalize](xxurl/Images/case_normalize.0.png)  <br>
├──104. [normalize_path](xxurl/Images/normalize_path.0.png)  <br>
├──111. [path_remove_consecutive_slashes](xxurl/Images/path_remove_consecutive_slashes.0.png)  <br>
├──112. [path_remove_dot_segments](xxurl/Images/path_remove_dot_segments.0.png)  <br>
├──.**_normalization_** <br>
├──113. [posixpath](xxurl/Images/posixpath.0.png)  <br>
├──114. [ptele2str](xxurl/Images/ptele2str.0.png)  <br>
├──115. [q2tl](xxurl/Images/q2tl.0.png)  <br>
├──116. [qdict2tl](xxurl/Images/qdict2tl.0.png)  <br>
├──117. [qdl2dict](xxurl/Images/qdl2dict.0.png)  <br>
├──118. [qdl2qtl](xxurl/Images/qdl2qtl.0.png)  <br>
├──119. [qtele2str](xxurl/Images/qtele2str.0.png)  <br>
├──120. [qtl2dict](xxurl/Images/qtl2dict.0.png)  <br>
├──121. [qtl2qdl](xxurl/Images/qtl2qdl.0.png)  <br>
├──.**_ordered urldecode urlencode_** <br>
├──122. [query_decode](xxurl/Images/query_decode.0.png)  <br>
├──123. [query_encode](xxurl/Images/query_encode.0.png)  <br>
├──.**_ordered urldecode urlencode_** <br>
├──125. [remove_fragment](xxurl/Images/remove_fragment.0.png)  <br>
├──126. [remove_host](xxurl/Images/remove_host.0.png)  <br>
├──127. [remove_hostname](xxurl/Images/remove_hostname.0.png)  <br>
├──128. [remove_netloc](xxurl/Images/remove_netloc.0.png)  <br>
├──129. [remove_params](xxurl/Images/remove_params.0.png)  <br>
├──130. [remove_password](xxurl/Images/remove_password.0.png)  <br>
├──131. [remove_path](xxurl/Images/remove_path.0.png)  <br>
├──132. [remove_port](xxurl/Images/remove_port.0.png)  <br>
├──133. [remove_protocol](xxurl/Images/remove_protocol.0.png)  <br>
├──134. [remove_query](xxurl/Images/remove_query.0.png)  <br>
├──135. [remove_scheme](xxurl/Images/remove_scheme.0.png)  <br>
├──136. [remove_unpw](xxurl/Images/remove_unpw.0.png)  <br>
├──137. [remove_userinfo](xxurl/Images/remove_userinfo.0.png)  <br>
├──138. [remove_username](xxurl/Images/remove_username.0.png)  <br>
├──139. [replace_fragment](xxurl/Images/replace_fragment.0.png)  <br>
├──140. [replace_host](xxurl/Images/replace_host.0.png)  <br>
├──141. [replace_hostname](xxurl/Images/replace_hostname.0.png)  <br>
├──142. [replace_netloc](xxurl/Images/replace_netloc.0.png)  <br>
├──143. [replace_params](xxurl/Images/replace_params.0.png)  <br>
├──144. [replace_password](xxurl/Images/replace_password.0.png)  <br>
├──145. [replace_path](xxurl/Images/replace_path.0.png)  <br>
├──146. [replace_port](xxurl/Images/replace_port.0.png)  <br>
├──147. [replace_protocol](xxurl/Images/replace_protocol.0.png)  <br>
├──148. [replace_query](xxurl/Images/replace_query.0.png)  <br>
├──149. [replace_scheme](xxurl/Images/replace_scheme.0.png)  <br>
├──150. [replace_unpw](xxurl/Images/replace_unpw.0.png)  <br>
├──151. [replace_userinfo](xxurl/Images/replace_userinfo.0.png)  <br>
├──152. [replace_username](xxurl/Images/replace_username.0.png)  <br>
├──153. [six_d2t](xxurl/Images/six_d2t.0.png)  <br>
├──154. [six_d2u](xxurl/Images/six_d2u.0.png)  <br>
├──155. [six_get](xxurl/Images/six_get.0.png)  <br>
├──156. [six_set](xxurl/Images/six_set.0.png)  <br>
├──157. [six_t2d](xxurl/Images/six_t2d.0.png)  <br>
├──158. [six_t2u](xxurl/Images/six_t2u.0.png)  <br>
├──159. [six_to_attrname](xxurl/Images/six_to_attrname.0.png)  <br>
├──160. [six_u2d](xxurl/Images/six_u2d.0.png)  <br>
├──161. [six_u2t](xxurl/Images/six_u2t.0.png)  <br>
├──162. [str2ptele](xxurl/Images/str2ptele.0.png)  <br>
├──163. [str2qtele](xxurl/Images/str2qtele.0.png)  <br>
├──164. [t2d](xxurl/Images/t2d.0.png)  <br>
├──165. [t2u](xxurl/Images/t2u.0.png)  <br>
├──166. [tl2para](xxurl/Images/tl2para.0.png)  <br>
├──167. [tl2q](xxurl/Images/tl2q.0.png)  <br>
├──169. [u2d](xxurl/Images/u2d.0.png)  <br>
├──170. [u2t](xxurl/Images/u2t.0.png)  <br>
├──171. [unpack_host](xxurl/Images/unpack_host.0.png)  <br>
├──172. [unpack_netloc](xxurl/Images/unpack_netloc.0.png)  <br>
├──173. [unpack_unpw](xxurl/Images/unpack_unpw.0.png)  <br>
├──.**_experimental_** <br>
├──174. [quote_chinese(s,codec='gb2312')](xxurl/Images/quote_chinese.0.png)  <br>
├──175. [urlpath2d](xxurl/Images/urlpath2d.0.png)  <br>
├──176. [get_path_last](xxurl/Images/get_path_last.0.png)  <br>
-----------------------------------------------------------------------


